# sphinxcontrib-analytics-hub

# Sphinx contrib Analytics

Sphinx extension for googleanalytics and baidu analytics .

Based on [sphinx-contrib/googleanalytics](https://github.com/sphinx-contrib/googleanalytics) and add baidu analytics .
